==> atmelwlandriver-3.3.5.6.tar.bz2: atmelwlandriver/src/includes/usb/appint.h <==
/***************************************************************************************
	Copyright 2000-2001 ATMEL Corporation.
	
	This file is part of atmel wireless lan drivers.

    Atmel wireless lan drivers is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Atmel wireless lan drivers is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Atmel wireless lan drivers; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

**************************************************************************************/
#ifndef __appint_h_ok_
#define __appint_h_ok_

#define	ESSID_SIZE				32
#define WEP_KEY_SIZE			13

#define MAX_BSS_ENTRIES			9
#define MAX_IBSS_ENTRIES		9

typedef struct __BSS_INFO{
	UCHAR	Channel;
	UCHAR	SSID[ESSID_SIZE];
	UCHAR	SSIDsize;
	UCHAR	BSSID[6];
	UCHAR	RSSI;
	UCHAR	UsingWEP;
	UCHAR	PreambleType;
	USHORT  BeaconPeriod;
	UCHAR	BSStype;
}BSS_INFO;

typedef struct __IBSS_INFO{
	UCHAR	MACaddress[6];
}IBSS_INFO;

typedef struct __STATISTICS{
	ULONG	TxDataPacketsOk;
	ULONG	TxDataPacketsError;
	ULONG	TxMgmtPacketsOk;
	ULONG	TxMgmtPacketsError;

	ULONG	RxDataPacketsOk;
	ULONG	RxDataPacketsError;
	ULONG	RxMgmtPacketsOk;
	ULONG	RxMgmtPacketsError;

	ULONG	RxLost;
	ULONG	TxPacketsRejectedNotReady;
	ULONG	TxPacketsRejectedResources;
	ULONG	MatchingBeacons;
}STATISTICS;

typedef struct __DEVICE_CONFIGURATION
{
	UCHAR			OperatingMode;					//AD_HOC_MODE or INFRASTRUCTURE_MODE
	UCHAR			Channel;
	UCHAR			SSID[ESSID_SIZE];
	UCHAR			SSIDlength;
	UCHAR			TxRate;							//0-4
	UCHAR			PowerMgmtMode;					// PM_MODE_ACTIVE or PM_MODE_POWER_SAVE
	UCHAR			InternationalRoaming;					// PM_MODE_ACTIVE or PM_MODE_POWER_SAVE
	UCHAR			RadioIsOn;					// PM_MODE_ACTIVE or PM_MODE_POWER_SAVE

	UCHAR			PreambleType;					// LONG_PREAMBLE or SHORT_PREAMBLE

	USHORT			FragmentationThreshold;
	USHORT			RtsCtsThreshold;

	UCHAR			BSSID[6];
	UCHAR			StationState;
	UCHAR			Rssi;
	UCHAR			LinkQuality;
	UCHAR			RegDomain;
        UCHAR                   ChannelVector[14];
	ULONG			MgmtErrorCode;
}DEVICE_CONFIGURATION, *PDEVICE_CONFIGURATION;

typedef struct __VERSION_INFO{
	UCHAR 	DriverMajorVersion;
	UCHAR 	DriverMinorVersion;
	UCHAR 	DriverSubVersion;
	USHORT	DriverBuild;
	USHORT	FwMajorVersion;
	USHORT	FwMinorVersion;
	USHORT	FwSubVersion;
	USHORT	FwBuild;
}VERSION_INFO;

#ifdef ATMEL_WLAN

typedef struct __WEP_INFO
{
	UCHAR	WepKeyToUse;
	UCHAR	WepMode;
	USHORT	AuthenticationType;
	UCHAR	EncryptionLevel;		//0:Disabled, 1:64bit, 2:128 bit
  UCHAR	GroupKeyIndex;
  UCHAR	PairwiseKeyIndex;
  UCHAR   PairwiseKeyLength;
  UCHAR	GroupKeyLength;
  UCHAR	PairwiseCipherSuite;
  UCHAR	GroupCipherSuite;
  UCHAR   BSSID[6];
  UCHAR	KeyIndex;
  UCHAR	KeyLength;
  UCHAR	SetKey;
  UCHAR	KeyMaterial[4][40];
  UCHAR	KeyRSC[4][8];
} WEP_INFO;

#else

typedef struct __WEP_INFO {
    UCHAR						WepKeyToUse;
	UCHAR						ExcludeUnencrypted;
	USHORT						AuthenticationType;
	UCHAR						EncryptionLevel;
	UCHAR						WepKey1[WEP_KEY_SIZE];
	UCHAR						WepKey2[WEP_KEY_SIZE];
	UCHAR						WepKey3[WEP_KEY_SIZE];
	UCHAR						WepKey4[WEP_KEY_SIZE];
} WEP_INFO, *PWEP_INFO;

#endif

typedef struct __SITE_SURVEY_INFO {
	BSS_INFO	BssInfo[MAX_BSS_ENTRIES];
	UCHAR		BSSInList;
	UCHAR		UserSelectedIndex;
	UCHAR		SiteSurveyState;
}SITE_SURVEY_INFO, *PSITE_SURVEY_INFO;
#endif //__appint_h_ok_

==> atmelwlandriver-3.4.1.0.tar.bz2: atmelwlandriver/src/includes/usb/appint.h <==
/***************************************************************************************
	Copyright 2000-2001 ATMEL Corporation.
	
	This file is part of atmel wireless lan drivers.

    Atmel wireless lan drivers is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Atmel wireless lan drivers is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Atmel wireless lan drivers; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

**************************************************************************************/
#ifndef __appint_h_ok_
#define __appint_h_ok_

#include "mib.h"
#define	ESSID_SIZE			32
#define WEP_KEY_SIZE			13

#define MAX_BSS_ENTRIES			9
#define MAX_IBSS_ENTRIES		9
#define MAX_IE_LENGTH                   400
#define MAX_WPA_IE_LEN                  64
#define MAX_SUPPORTED_RATES_LENGTH                                     16
#define MAX_PAIRWISE_SUITES 4
#define MAX_AUTH_MGMT_SUITES 4
typedef struct __WPA_INFO
{
	USHORT	Version;
	UCHAR	GroupSuite;
	USHORT	PairwiseSuiteCnt;
	UCHAR	PairwiseSuiteList[MAX_PAIRWISE_SUITES];
	USHORT	AuthMgmtSuiteCnt;
	UCHAR	AuthMgmtSuiteList[MAX_AUTH_MGMT_SUITES];
	UCHAR	WpaCapabilities[2];
} WPA_INFO, *PWPA_INFO;
#define BSS_CAPAPILITY_WPA		1
#define BSS_CAPAPILITY_CCX		2
#define MAX_SSID_LENGTH                 32
#define MAX_SUPPORTED_RATES_LENGTH	16
typedef struct __BSS_INFO_EX{
	UCHAR	Channel;
	UCHAR	SSID[MAX_SSID_LENGTH];
	UCHAR	SSIDsize;
	UCHAR	BSSID[6];
	CHAR	RSSI;
  UCHAR EncryptionIsOn;
	UCHAR	PreambleType;
	USHORT  BeaconPeriod;
	UCHAR	BSStype;
	UCHAR	BeaconProbeInfo[MAX_IE_LENGTH];
	USHORT	BeaconProbeLen;
  UCHAR   WpaIE[MAX_WPA_IE_LEN * 2 + 30];
  USHORT  WpaIELen;
	ULONG	Capabilities;
	UCHAR	FailedToConnect;
	WPA_INFO WpaInfo;
  WPA_INFO Wpa2Info;
	UCHAR	SupportedRatesLength;
	UCHAR	SupportedRates[MAX_SUPPORTED_RATES_LENGTH];
}BSS_INFO_EX, *PBSS_INFO_EX;

#if 0
typedef struct __BSS_INFO{
	UCHAR	Channel;
	UCHAR	SSID[ESSID_SIZE];
	UCHAR	SSIDsize;
	UCHAR	BSSID[6];
	UCHAR	RSSI;
	UCHAR	UsingWEP;
	UCHAR	PreambleType;
	USHORT  BeaconPeriod;
	UCHAR	BSStype;
}BSS_INFO;
#endif

typedef struct __IBSS_INFO{
	UCHAR	MACaddress[6];
}IBSS_INFO;

#if 0
typedef struct __STATISTICS{
	ULONG	TxDataPacketsOk;
	ULONG	TxDataPacketsError;
	ULONG	TxMgmtPacketsOk;
	ULONG	TxMgmtPacketsError;

	ULONG	RxDataBytes;
	ULONG	RxDataPacketsOk;
	ULONG	RxDataPacketsError;
	ULONG	RxMgmtPacketsOk;
	ULONG	RxMgmtPacketsError;

	ULONG	RxLost;
	ULONG	TxPacketsRejectedNotReady;
	ULONG	TxPacketsRejectedResources;
	ULONG	MatchingBeacons;
}STATISTICS;
#endif
typedef struct __STATISTICS{
	ULONG	TxDataPacketsOk;
	ULONG	TxDataPacketsError;
	ULONG	TxMgmtPacketsOk;
	ULONG	TxMgmtPacketsError;
	ULONG	RxDataPacketsOk;
	ULONG	RxDataPacketsError;
	ULONG	RxMgmtPacketsOk;
	ULONG	RxMgmtPacketsError;
	ULONG	RxLost;
	ULONG	TxPacketsRejectedNotReady;
	ULONG	TxPacketsRejectedResources;
	ULONG	MatchingBeacons;

	ULONG	RxWpaMicErrors;
	ULONG	RxWpaCountermeasuresCount;
	ULONG	RxWpaReplayErrors;
	ULONG	WpaBlackListEntries;

	ULONG	Reserved1;
	ULONG	Reserved2;
	ULONG	Reserved3;
	ULONG	Reserved4;
	
}STATISTICS;

typedef struct __DEVICE_CONFIGURATION
{
	UCHAR			OperatingMode;					//AD_HOC_MODE or INFRASTRUCTURE_MODE
	UCHAR			Channel;
	UCHAR			SSID[ESSID_SIZE];
	UCHAR			SSIDlength;
	UCHAR			TxRate;							//0-4
	UCHAR			PowerMgmtMode;					// PM_MODE_ACTIVE or PM_MODE_POWER_SAVE
        UCHAR                   TxPowerLevel;
	UCHAR			InternationalRoaming;					// PM_MODE_ACTIVE or PM_MODE_POWER_SAVE
	UCHAR			RadioIsOn;					// PM_MODE_ACTIVE or PM_MODE_POWER_SAVE

	UCHAR			PreambleType;					// LONG_PREAMBLE or SHORT_PREAMBLE

	USHORT			FragmentationThreshold;
	USHORT			RtsCtsThreshold;

	UCHAR			BSSID[6];
	UCHAR			StationState;
	UCHAR			Rssi;
	UCHAR			LinkQuality;
	UCHAR			RegDomain;
        UCHAR                   ChannelVector[14];
	ULONG			MgmtErrorCode;
}DEVICE_CONFIGURATION, *PDEVICE_CONFIGURATION;

typedef struct __VERSION_INFO{
	UCHAR 	DriverMajorVersion;
	UCHAR 	DriverMinorVersion;
	UCHAR 	DriverSubVersion;
	USHORT	DriverBuild;
	USHORT	FwMajorVersion;
	USHORT	FwMinorVersion;
	USHORT	FwSubVersion;
	USHORT	FwBuild;
}VERSION_INFO;

#ifdef ATMEL_WLAN

typedef struct __ENCRYPTION_INFO
{
	UCHAR	WepKeyToUse;
	UCHAR	WepMode;
	USHORT	AuthenticationMode;
	UCHAR	EncryptionLevel;		//0:Disabled, 1:64bit, 2:128 bit
  UCHAR	GroupKeyIndex;
  UCHAR	PairwiseKeyIndex;
  UCHAR   PairwiseKeyLength;
  UCHAR	GroupKeyLength;
  UCHAR	PairwiseCipherSuite;
  UCHAR	GroupCipherSuite;
  UCHAR   BSSID[6];
  UCHAR	KeyIndex;
  UCHAR	KeyLength;
  UCHAR	SetKey;
  UCHAR	KeyMaterial[4][40];
  UCHAR	KeyRSC[4][8];
} ENCRYPTION_INFO, *PENCRYPTION_INFO;

#else

typedef struct __WEP_INFO {
    UCHAR						WepKeyToUse;
	UCHAR						ExcludeUnencrypted;
	USHORT						AuthenticationType;
	UCHAR						EncryptionLevel;
	UCHAR						WepKey1[WEP_KEY_SIZE];
	UCHAR						WepKey2[WEP_KEY_SIZE];
	UCHAR						WepKey3[WEP_KEY_SIZE];
	UCHAR						WepKey4[WEP_KEY_SIZE];
} WEP_INFO, *PWEP_INFO;

#endif

typedef struct __SITE_SURVEY_INFO {
	BSS_INFO_EX	BssInfo[MAX_BSS_ENTRIES];
	UCHAR		BSSInList;
	UCHAR		UserSelectedIndex;
	UCHAR		SiteSurveyState;
}SITE_SURVEY_INFO, *PSITE_SURVEY_INFO;

#define MAX_KEY_LENGTH      40

struct atmel_param{
    unsigned char sta_addr[6];
    int     cmd;
    UCHAR      alg;
    UCHAR      key_idx;
    UCHAR      set_tx;
    UCHAR      seq[8];
    UCHAR      seq_len;
    USHORT     key_len;
    UCHAR      key[MAX_KEY_LENGTH];
    struct{
        int     reason_code;
        UCHAR      state;
    }mlme;
    UCHAR          pairwise_suite;
    UCHAR          group_suite;
    UCHAR          key_mgmt_suite;
};

#endif //__appint_h_ok_
